ui_print " "

# check magisk manager
if [ "$BOOTMODE" != true ]; then
  abort "- Please flash via Magisk Manager only!"
fi

# attention
ui_print "- Module created by Rei Ryuki the Fixer"
ui_print " "

# check sdk
if [ "$API" -lt 28 ]; then
  ui_print "! Unsupported SDK $API. You have to upgrade your"
  ui_print "  Android version at least SDK API 28 to use this module."
  abort
else
  ui_print "- SDK $API"
  ui_print " "
fi

# check se patch
RULE=${MAGISKTMP}/mirror/persist/magisk/$MODID
mkdir -p $RULE
if [ ! -d $RULE ]; then
  ui_print "- Se policy patch will fail. Using permissive method"
  ui_print "  instead..."
  ui_print " "
  SELINUX=`getenforce`
  if [ "$SELINUX" == Enforcing ]; then
    setenforce 0
    SELINUX=`getenforce`
    if [ "$SELINUX" == Enforcing ]; then
      abort "! Your device can't be turned to Permissive state."
    fi
    setenforce 1
  fi
  sed -i '1i\
SELINUX=`getenforce`\
if [ "$SELINUX" == Enforcing ]; then\
  setenforce 0\
fi\' $MODPATH/service.sh
fi

# store
patch_manifest() {
  mount -o rw,remount $MOUNT
  if [ ! -f $MFX.orig ]; then
    cp -f $MFX $MFX.orig
  fi
  sed -i '/<manifest/a\
    <hal format="hidl">\
        <name>vendor.dolby.hardware.dms</name>\
        <transport>hwbinder</transport>\
        <version>1.0</version>\
        <interface>\
            <name>IDms</name>\
            <instance>default</instance>\
        </interface>\
        <fqname>@1.0::IDms/default</fqname>\
    </hal>' $MFX
  mount -o ro,remount $MOUNT
}
is_patched() {
  ui_print "- $MFX"
  ui_print "  is already patched."
  ui_print " "
}
check_patch() {
  if ! grep -Eq "@1.0::IDms/default" $MFX; then
    ui_print "! Patching failed. Tap save button in the top right"
    ui_print "  corner and send the install logs to developer. Also"
    ui_print "  send /proc/mounts file."
    abort
  fi
}

# patch system manifest
if [ -d ${MAGISKTMP}/mirror/system_root ]; then
  MOUNT=${MAGISKTMP}/mirror/system_root
  MFX=${MAGISKTMP}/mirror/system_root/system/etc/vintf/manifest.xml
else
  MOUNT=${MAGISKTMP}/mirror/system
  MFX=${MAGISKTMP}/mirror/system/etc/vintf/manifest.xml
fi
if ! grep -Eq "@1.0::IDms/default" $MFX; then
  ui_print "- Patching"
  ui_print "  $MFX"
  ui_print "  directly..."
  patch_manifest
  ui_print " "
else
  is_patched
fi

# patch vendor manifest
if ! grep -Eq "@1.0::IDms/default" $MFX; then
  ui_print "-  Failed to patch in /system."
  MOUNT=${MAGISKTMP}/mirror/vendor
  MFX=${MAGISKTMP}/mirror/vendor/etc/vintf/manifest.xml
  if ! grep -Eq "@1.0::IDms/default" $MFX; then
    ui_print "  Patching"
    ui_print "  $MFX"
    ui_print "  instead..."
    patch_manifest
    ui_print " "
    check_patch
  else
    is_patched
  fi
fi

# check bit
if [ "$IS64BIT" != true ]; then
  ui_print "- 32 bit"
  cp -rf $MODPATH/system32/* $MODPATH/system
  rm -rf `find $MODPATH/system -type d -name *64`
  rm -f $MODPATH/system/vendor/etc/media_codecs_dolby.xml
  rm -f $MODPATH/system.prop
  ui_print " "
else
  ui_print "- 64 bit"
  ui_print " "
fi

# cleaning
ui_print "- Cleaning..."
APP1=DaxUI
APP2=daxService
PKGCACHE=/data/system/package_cache
rm -f $MODPATH/LICENSE
rm -rf $MODPATH/system32
rm -f `find /data/dalvik-cache -type f -name *$APP1*`
rm -f `find /data/dalvik-cache -type f -name *$APP2*`
rm -f `find $PKGCACHE -type f -name $APP1*`
rm -f `find $PKGCACHE -type f -name $APP2*`
rm -f `find $PKGCACHE -type f -name com.dolby.daxappui*`
rm -f `find $PKGCACHE -type f -name com.dolby.service*`
ui_print " "

# setting permission, owner, and se context
ui_print "- Setting permission, owner, and SE context..."
chmod 0755 $MODPATH/system/vendor/bin/hw/*
chown 0.2000 $MODPATH/system/vendor
chown -R 0.2000 $MODPATH/system/vendor/bin
chown 0.2000 $MODPATH/system/vendor/etc
chown 0.2000 $MODPATH/system/vendor/etc/dolby
chown 0.2000 $MODPATH/system/vendor/lib*
chcon -R u:object_r:vendor_file:s0 $MODPATH/system/vendor
chcon -R u:object_r:vendor_configs_file:s0 $MODPATH/system/vendor/etc
#SERVICE=vendor.dolby.hardware.dms@1.0-service
#chcon u:object_r:hal_dms_default_exec:s0 $MODPATH/system/vendor/bin/hw/$SERVICE
ui_print " "



